pub struct WithImports {}runtime and crate feature component-model and (docsrs) only.Expand description
Auto-generated bindings for an instance a component which
implements the world with-imports.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
WithImports::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
WithImportsPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesWithImportsPre::instantiateto create aWithImports. -
If you’ve instantiated the instance yourself already then you can use
WithImports::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl WithImports
impl WithImports
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<WithImports>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<WithImports>
Convenience wrapper around WithImportsPre::new and
WithImportsPre::instantiate.
Sourcepub fn new(store: impl AsContextMut, instance: &Instance) -> Result<WithImports>
pub fn new(store: impl AsContextMut, instance: &Instance) -> Result<WithImports>
Convenience wrapper around WithImportsIndices::new and
WithImportsIndices::load.
Sourcepub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<WithImports>where
_T: Send,
pub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<WithImports>where
_T: Send,
Convenience wrapper around WithImportsPre::new and
WithImportsPre::instantiate_async.
pub fn add_to_linker<T, D>( linker: &mut Linker<T>, host_getter: fn(&mut T) -> D::Data<'_>, ) -> Result<()>