pub struct ImportSomeResources {}runtime and crate feature component-model and (docsrs) only.Expand description
Auto-generated bindings for an instance a component which
implements the world import-some-resources.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
ImportSomeResources::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
ImportSomeResourcesPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesImportSomeResourcesPre::instantiateto create aImportSomeResources. -
If you’ve instantiated the instance yourself already then you can use
ImportSomeResources::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl ImportSomeResources
impl ImportSomeResources
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<ImportSomeResources>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<ImportSomeResources>
Convenience wrapper around ImportSomeResourcesPre::new and
ImportSomeResourcesPre::instantiate.
Sourcepub fn new(
store: impl AsContextMut,
instance: &Instance,
) -> Result<ImportSomeResources>
pub fn new( store: impl AsContextMut, instance: &Instance, ) -> Result<ImportSomeResources>
Convenience wrapper around ImportSomeResourcesIndices::new and
ImportSomeResourcesIndices::load.
Sourcepub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<ImportSomeResources>where
_T: Send,
pub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<ImportSomeResources>where
_T: Send,
Convenience wrapper around ImportSomeResourcesPre::new and
ImportSomeResourcesPre::instantiate_async.
pub fn add_to_linker<T, D>( linker: &mut Linker<T>, host_getter: fn(&mut T) -> D::Data<'_>, ) -> Result<()>