pub struct MyLogger {
pub max_level: Level,
}Available on crate feature
runtime and crate feature component-model and (docsrs) only.Expand description
A sample host-defined type which contains arbitrary host-defined data.
In this case this is relatively simple but there’s no restrictions on what
this type can hold other than that it must be 'static + Send.
Fields
max_level: LevelAuto Trait Implementations
impl Freeze for MyLogger
impl RefUnwindSafe for MyLogger
impl Send for MyLogger
impl Sync for MyLogger
impl Unpin for MyLogger
impl UnsafeUnpin for MyLogger
impl UnwindSafe for MyLogger