pub struct MyWorld { /* private fields */ }runtime and crate feature component-model and (docsrs) and crate feature component-model-async only.Expand description
Auto-generated bindings for an instance a component which
implements the world my-world.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
MyWorld::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
MyWorldPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesMyWorldPre::instantiateto create aMyWorld. -
If you’ve instantiated the instance yourself already then you can use
MyWorld::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl MyWorld
impl MyWorld
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<MyWorld>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<MyWorld>
Convenience wrapper around MyWorldPre::new and
MyWorldPre::instantiate.
Sourcepub fn new(store: impl AsContextMut, instance: &Instance) -> Result<MyWorld>
pub fn new(store: impl AsContextMut, instance: &Instance) -> Result<MyWorld>
Convenience wrapper around MyWorldIndices::new and
MyWorldIndices::load.
Sourcepub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<MyWorld>where
_T: Send,
pub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<MyWorld>where
_T: Send,
Convenience wrapper around MyWorldPre::new and
MyWorldPre::instantiate_async.
pub fn add_to_linker_imports<T, D>( linker: &mut Linker<T>, host_getter: fn(&mut T) -> D::Data<'_>, ) -> Result<()>
pub fn add_to_linker<T, D>(
linker: &mut Linker<T>,
host_getter: fn(&mut T) -> D::Data<'_>,
) -> Result<()>where
D: MyWorldImportsWithStore + Send,
for<'a> D::Data<'a>: MyWorldImports + Send,
T: 'static + Send,
pub async fn call_run<_T, _D>(&self, accessor: &Accessor<_T, _D>) -> Result<()>