pub unsafe trait Lift: Sized + ComponentType { }Available on crate feature
component-model only.Expand description
Host types which can be created from the canonical ABI.
Object Safety
This trait is not object safe.
pub unsafe trait Lift: Sized + ComponentType { }component-model only.Host types which can be created from the canonical ABI.