pub enum CodeHint {
Module,
Component,
}Available on crate features
cranelift or winch only.Expand description
Return value of CodeBuilder::hint
Variants
Module
Hint that the code being compiled is a module.
Component
Hint that the code being compiled is a component.