#[non_exhaustive]pub enum InstanceAllocationStrategy {
OnDemand,
Pooling(PoolingAllocationConfig),
}Expand description
Represents the module instance allocation strategy to use.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
OnDemand
The on-demand instance allocation strategy.
Resources related to a module instance are allocated at instantiation time and
immediately deallocated when the Store referencing the instance is dropped.
This is the default allocation strategy for Wasmtime.
Pooling(PoolingAllocationConfig)
pooling-allocator only.The pooling instance allocation strategy.
A pool of resources is created in advance and module instantiation reuses resources
from the pool. Resources are returned to the pool when the Store referencing the instance
is dropped.
When GC is enabled, the pooling allocator requires that the GC heap
configuration matches the linear memory configuration (i.e.,
gc_heap_reservation must equal memory_reservation, etc.). By
default, if no gc_heap_* tunables are explicitly configured, they
automatically inherit the memory_* values.
Implementations