pub enum ModuleVersionStrategy {
WasmtimeVersion,
Custom(String),
None,
}Expand description
Configure the strategy used for versioning in serializing and deserializing crate::Module.
Variants
WasmtimeVersion
Use the wasmtime crate’s Cargo package version.
Custom(String)
Use a custom version string. Must be at most 255 bytes.
None
Emit no version string in serialization, and accept all version strings in deserialization.
Implementations