ArrayRefPre

Struct ArrayRefPre 

pub struct ArrayRefPre { /* private fields */ }
Available on crate features gc and runtime only.
An allocator for a particular Wasm GC array type.

Every ArrayRefPre is associated with a particular Store and a particular ArrayType.

Reusing an allocator across many allocations amortizes some per-type runtime overheads inside Wasmtime. An ArrayRefPre is to ArrayRefs as an InstancePre is to Instances.

Example

use wasmtime::*;

let mut config = Config::new();
config.wasm_function_references(true);
config.wasm_gc(true);

let engine = Engine::new(&config)?;
let mut store = Store::new(&engine, ());

// Define an array type.
let array_ty = ArrayType::new(
   store.engine(),
   FieldType::new(Mutability::Var, ValType::I32.into()),
);

// Create an allocator for the array type.
let allocator = ArrayRefPre::new(&mut store, array_ty);

{
    let mut scope = RootScope::new(&mut store);

    // Allocate a bunch of instances of our array type using the same
    // allocator! This is faster than creating a new allocator for each
    // instance we want to allocate.
    for i in 0..10 {
        let len = 42;
        let elem = Val::I32(36);
        ArrayRef::new(&mut scope, &allocator, &elem, len)?;
    }
}

Implementations

Source

impl ArrayRefPre

pub fn new(store: impl AsContextMut, ty: ArrayType) -> Self

Create a new ArrayRefPre that is associated with the given store and type.

Panics

Panics if ty was not created with the same Engine as store.