pub struct ModuleFunction {
pub module: StaticModuleIndex,
pub index: FuncIndex,
pub name: Option<String>,
pub offset: usize,
pub len: usize,
}Expand description
Describes a function for a given module.
Fields
module: StaticModuleIndexThe static module index this function belongs to.
index: FuncIndexThe function index within the module.
name: Option<String>The display name of the function, if available.
offset: usizeThe byte offset of this function in the text section.
len: usizeThe byte length of this function in the text section.