Struct ModulePC
pub struct ModulePC(/* private fields */);Expand description
A Wasm bytecode offset relative to the start of a core Wasm module binary.
In the guest-debug system, PCs are always module-relative because the debugger presents a core-Wasm view of the world where components are deconstructed into individual core Wasm modules.
For standalone (non-component) modules, ModulePC and
[ComponentPC] values are numerically identical.
Implementations