StaticModuleIndex

Struct StaticModuleIndex 

pub struct StaticModuleIndex(/* private fields */);
Index into the global list of modules found within an entire component.

Module translations are saved on the side to get fully compiled after the original component has finished being translated.

Implementations



impl StaticModuleIndex

pub fn from_u32(x: u32) -> StaticModuleIndex

Create a new instance from a u32.

pub fn as_u32(self) -> u32

Return the underlying index value as a u32.

pub fn as_bits(self) -> u32

Return the raw bit encoding for this instance.

Warning: the raw bit encoding is opaque and has no guaranteed correspondence to the entity’s index. It encodes the entire state of this index value: either a valid index or an invalid-index sentinel. The value returned by this method should only be passed to from_bits.

pub fn from_bits(x: u32) -> StaticModuleIndex

Create a new instance from the raw bit encoding.

Warning: the raw bit encoding is opaque and has no guaranteed correspondence to the entity’s index. It encodes the entire state of this index value: either a valid index or an invalid-index sentinel. The value returned by this method should only be given bits from as_bits.