StructRefPre

Struct StructRefPre 

pub struct StructRefPre { /* private fields */ }
Available on crate features gc and runtime only.
An allocator for a particular Wasm GC struct type.

Every StructRefPre is associated with a particular Store and a particular StructType.

Reusing an allocator across many allocations amortizes some per-type runtime overheads inside Wasmtime. A StructRefPre is to StructRefs as an InstancePre is to Instances.

Example

use wasmtime::*;

let mut config = Config::new();
config.wasm_function_references(true);
config.wasm_gc(true);

let engine = Engine::new(&config)?;
let mut store = Store::new(&engine, ());

// Define a struct type.
let struct_ty = StructType::new(
   store.engine(),
   [FieldType::new(Mutability::Var, StorageType::I8)],
)?;

// Create an allocator for the struct type.
let allocator = StructRefPre::new(&mut store, struct_ty);

{
    let mut scope = RootScope::new(&mut store);

    // Allocate a bunch of instances of our struct type using the same
    // allocator! This is faster than creating a new allocator for each
    // instance we want to allocate.
    for i in 0..10 {
        StructRef::new(&mut scope, &allocator, &[Val::I32(i)])?;
    }
}

Implementations

Source

impl StructRefPre

pub fn new(store: impl AsContextMut, ty: StructType) -> Self

Create a new StructRefPre that is associated with the given store and type.

Panics

Panics if ty was not created with the same Engine as store.