pub struct Tag { /* private fields */ }Expand description
A WebAssembly tag.
Implementations
Sourceimpl Tag
impl Tag
Sourcepub fn new(store: impl AsContextMut, ty: &TagType) -> Result<Tag>
Available on crate feature runtime only.
pub fn new(store: impl AsContextMut, ty: &TagType) -> Result<Tag>
runtime only.Create a new tag instance from a given TagType.
Sourcepub fn debug_index_in_store(&self) -> u64
Available on crate features runtime and debug only.
pub fn debug_index_in_store(&self) -> u64
runtime and debug only.Returns a stable identifier for this tag within its store.
This allows distinguishing tags when introspecting them e.g. via debug APIs.