Struct VariableOperatorCost
pub struct VariableOperatorCost {Show 16 fields
pub memory_copy_per_byte: u8,
pub memory_fill_per_byte: u8,
pub memory_init_per_byte: u8,
pub memory_grow_per_page: u8,
pub table_copy_per_element: u8,
pub table_fill_per_element: u8,
pub table_init_per_element: u8,
pub table_grow_per_element: u8,
pub array_copy_per_element: u8,
pub array_fill_per_element: u8,
pub array_new_data_per_element: u8,
pub array_init_data_per_element: u8,
pub array_new_elem_per_element: u8,
pub array_init_elem_per_element: u8,
pub array_new_default_per_element: u8,
pub array_new_per_element: u8,
}Expand description
Fuel costs for operators whose work is proportional to a runtime operand.
These costs are charged in addition to the corresponding flat cost in
OperatorCost.
Fields
memory_copy_per_byte: u8Cost per byte copied by memory.copy.
memory_fill_per_byte: u8Cost per byte written by memory.fill.
memory_init_per_byte: u8Cost per byte copied by memory.init.
memory_grow_per_page: u8Cost per page requested by memory.grow.
table_copy_per_element: u8Cost per element copied by table.copy.
table_fill_per_element: u8Cost per element written by table.fill.
table_init_per_element: u8Cost per element copied by table.init.
table_grow_per_element: u8Cost per element requested by table.grow.
array_copy_per_element: u8Cost per element copied by array.copy.
array_fill_per_element: u8Cost per element written by array.fill.
array_new_data_per_element: u8Cost per element initialized by array.new_data.
array_init_data_per_element: u8Cost per element initialized by array.init_data.
array_new_elem_per_element: u8Cost per element initialized by array.new_elem.
array_init_elem_per_element: u8Cost per element initialized by array.init_elem.
array_new_default_per_element: u8Cost per element initialized by array.new_default.
array_new_per_element: u8Cost per element initialized by array.new.
Implementations
impl VariableOperatorCost
impl VariableOperatorCost
pub const fn new() -> VariableOperatorCost
pub const fn new() -> VariableOperatorCost
Creates the default variable-cost table.