pub struct WasmtimeBug { /* private fields */ }Available on crate feature
component-model-async only.Expand description
Error which indicates a bug in Wasmtime.
This structure is used internally with Wasmtime for situations which are a bug in Wasmtime but not serious enough to raise a panic and unwind the current thread of execution. In these situations this is still considered a bug and a trap is raised to terminate a guest, and it’s considered something that needs to be fixed in Wasmtime.