pub trait IntoFunc<T, Params, Results>:
Send
+ Sync
+ 'static { }Available on crate feature
runtime only.Expand description
Internal trait implemented for all arguments that can be passed to
Func::wrap and Linker::func_wrap.
This trait should not be implemented by external users, it’s only intended as an implementation detail of this crate.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".