Available on crate feature
component-model only.Expand description
In-progress implementation of the WebAssembly component model
This module is a work-in-progress and currently represents an incomplete and probably buggy implementation of the component model.
Re-exports
pub use self::types::ResourceType;pub use self::types::Type;
Modules
- This module defines the
Typetype, representing the dynamic form of a component interface type.
Macros
- Generate bindings for a WIT package.
Structs
- A compiled WebAssembly Component.
- Represents runtime enum values
- Description of the exports of a single instance.
- Description of the exports of an
Instance. - Represents runtime flag values
- A WebAssembly component function.
- An instantiated component.
- A “pre-instantiated”
Instancewhich has all of its arguments already supplied and is ready to instantiate. - A type used to instantiate
Components. - Structure representing an “instance” being defined within a linker.
- Represents runtime list values
- Represents runtime option values
- Represents runtime record values
- A host-defined resource in the component model.
- Representation of a resource in the component model, either a guest-defined or a host-defined resource.
- Index correlating a resource definition to the import path. This is assigned by
Linker::resourceand may be used to associate it toRuntimeImportIndexat a later stage - The
ResourceTabletype maps aResource<T>to itsT. - Represents runtime result values
- Represents runtime tuple values
- Represents runtime variant values
- Representation of a list of values that are owned by a WebAssembly instance.
- Representation of a string located in linear memory in a WebAssembly instance.
Enums
- Errors returned by operations on
ResourceTable - Represents possible runtime values which a component function can either consume or produce
Traits
- A trait representing a static list of named types that can be passed to or returned from a
TypedFunc. - A trait representing types which can be passed to and read from components with the canonical ABI.
- Host types which can be created from the canonical ABI.
- Host types which can be passed to WebAssembly components.