ExportLookup

Trait ExportLookup 

pub trait ExportLookup { }
Available on crate features runtime and component-model only.
Trait used to lookup the export of a component or instance.

This trait is used as an implementation detail of Instance::get_func. and related get_* methods, as well as Component::get_export and related get_* methods. Notable implementors of this trait are:

Note that this is intended to be a wasmtime-sealed trait so it shouldn’t need to be implemented externally.

Implementations on Foreign Types

Source

impl ExportLookup for str

Source

impl ExportLookup for String

Source

impl ExportLookup for ItemName

Available on crate feature wit-parser only.
Source

impl<T> ExportLookup for &T
where T: ExportLookup + ?Sized,

Implementors