pub trait ExportLookup { }Available on crate features
runtime and component-model only.Expand description
Trait used to lookup the export of a component or instance.
This trait is used as an implementation detail of
Instance::get_func.
and related get_* methods, as well as Component::get_export and
related get_* methods. Notable implementors of this trait are:
strStringComponentExportIndex
Note that this is intended to be a wasmtime-sealed trait so it shouldn’t
need to be implemented externally.
Implementations on Foreign Types
impl ExportLookup for str
impl ExportLookup for String
impl ExportLookup for ItemName
Available on crate feature
wit-parser only.