pub enum DebugEvent<'a> {
HostcallError(&'a Error),
Exception(OwnedRooted<ExnRef>),
Trap(Trap),
Breakpoint,
EpochYield,
}Available on crate feature
debug only.Expand description
One debug event that occurs when running Wasm code on a store with a debug handler attached.
Variants
HostcallError(&'a Error)
A wasmtime::Error was raised by a hostcall.
Exception(OwnedRooted<ExnRef>)
An exception is thrown by wasm.
Note that the exception may be caught by wasm if there’s an appropriate handler on the stack, but the stack hasn’t been searched yet. The debugger can inject its own exception or overwrite this exception if desired.
Trap(Trap)
A Wasm trap occurred.
Breakpoint
A breakpoint was reached.
EpochYield
An epoch yield occurred.