Enum wasmtime::Extern [−][src]
pub enum Extern {
Func(Func),
Global(Global),
Table(Table),
Memory(Memory),
Instance(Instance),
Module(Module),
}Expand description
An external item to a WebAssembly module, or a list of what can possibly be exported from a wasm module.
This is both returned from Instance::exports
as well as required by Instance::new. In other
words, this is the type of extracted values from an instantiated module, and
it’s also used to provide imported values when instantiating a module.
Variants
Func(Func)A WebAssembly func which can be called.
Global(Global)A WebAssembly global which acts like a Cell<T> of sorts, supporting
get and set operations.
Table(Table)A WebAssembly table which is an array of Val reference types.
Memory(Memory)A WebAssembly linear memory.
Instance(Instance)A WebAssembly instance.
Module(Module)A WebAssembly module.
Implementations
Returns the underlying Func, if this external is a function.
Returns None if this is not a function.
Returns the underlying Global, if this external is a global.
Returns None if this is not a global.
Returns the underlying Table, if this external is a table.
Returns None if this is not a table.
Returns the underlying Memory, if this external is a memory.
Returns None if this is not a memory.
Returns the underlying Instance, if this external is a instance.
Returns None if this is not a instance.
Returns the underlying Module, if this external is a module.
Returns None if this is not a module.
Returns the type associated with this Extern.
The store argument provided must own this Extern and is used to look
up type information.
Panics
Panics if this item does not belong to the store provided.