pub struct TagType { /* private fields */ }Available on crate feature
runtime only.Expand description
A descriptor for a tag in a WebAssembly module.
Note that tags are local to an Instance,
i.e., are a runtime entity. However, a tag is associated with a
function type, and so has a kind of static type. This descriptor
is a thin wrapper around a FuncType representing the function
type of a tag.
Implementations
Sourceimpl TagType
impl TagType
Sourcepub fn default_value(&self, store: impl AsContextMut) -> Result<RuntimeTag>
pub fn default_value(&self, store: impl AsContextMut) -> Result<RuntimeTag>
Construct a new default tag with this type.
This creates a host Tag in the given store. Tag instances
have no content other than their type, so this “default” value
is identical to ordinary host tag allocation.